% This file plots comparison graphs for CZT vs. GGA computing times
% Determine what plots to show by setting appropriate true/false flags

% 2013 Pavel Rajmic, Brno University of Technology, Czech Republic


clc
clear all
close all


%% Setting up
%Set to true if absolute timings have to be displayed for all machines and all lengths
plot_all_graphs_absolute =  false %true %

%Set to true if relative timings have to be displayed for all machines and all lengths
plot_all_graphs_relative = false %true %

%Set to true if averaged relative timings have to be displayed for all lengths
plot_all_graphs_relative_average = true % false % 

%Anchor method for relative analysis
anchor = 1  %1....GGA with precomputed exponentials

%Markers for plotting
markers = '.+o*xdv';
colors = 'krgbcm'; % 'kbymrg';


%% Load data
directory = '../measured/'
load ([directory 'K_and_rep.mat'])  %vector of Ks and no of repetitions

data_to_analyze = cell(0);
weights = [];
machine_labels = cell(0);

%Zdenek Prusa desktop
data_to_analyze = [data_to_analyze {'cztvsgga_25-Oct-2013_18-12-16-Prusa.mat'}];
weights(end+1) = 1;
machine_labels(end+1) = {'Machine A'};

%Vaclav Mach desktop
data_to_analyze = [data_to_analyze {'cztvsgga_27-Oct-2013_07-55-17-Mach_PC_skolni.mat'}];
weights(end+1) = 1;
machine_labels(end+1) = {'Machine B'};

%Vaclav Mach notebook
data_to_analyze = [data_to_analyze {'cztvsgga_27-Oct-2013_07-51-33-Mach_notebook.mat'}];
weights(end+1) = 1;
machine_labels(end+1) = {'Machine C'};

% SC5.113 laboratory computer
data_to_analyze = [data_to_analyze {'cztvsgga_29-Oct-2013_08-06-41-SC5.113.mat'}];
weights(end+1) = 1/5;
machine_labels(end+1) = {'Machine D'};
data_to_analyze = [data_to_analyze {'cztvsgga_29-Oct-2013_08-10-49-SC5.113.mat'}];
weights(end+1) = 1/5;
machine_labels(end+1) = {'Machine D'};
data_to_analyze = [data_to_analyze {'cztvsgga_29-Oct-2013_08-14-50-SC5.113.mat'}];
weights(end+1) = 1/5;
machine_labels(end+1) = {'Machine D'};
data_to_analyze = [data_to_analyze {'cztvsgga_29-Oct-2013_08-17-17-SC5.113.mat'}];
weights(end+1) = 1/5;
machine_labels(end+1) = {'Machine D'};
data_to_analyze = [data_to_analyze {'cztvsgga_29-Oct-2013_08-29-28-SC5.113.mat'}];
weights(end+1) = 1/5;

% SC5.127 laboratory computer
data_to_analyze = [data_to_analyze {'cztvsgga_01-Nov-2013_14-50-01-SC5.127.mat'}];
weights(end+1) = 1/5;
machine_labels(end+1) = {'Machine E'};
data_to_analyze = [data_to_analyze {'cztvsgga_01-Nov-2013_14-51-58-SC5.127.mat'}];
weights(end+1) = 1/5;
machine_labels(end+1) = {'Machine E'};
data_to_analyze = [data_to_analyze {'cztvsgga_01-Nov-2013_14-54-42-SC5.127.mat'}];
weights(end+1) = 1/5;
machine_labels(end+1) = {'Machine E'};
data_to_analyze = [data_to_analyze {'cztvsgga_01-Nov-2013_14-56-53-SC5.127.mat'}];
weights(end+1) = 1/5;
machine_labels(end+1) = {'Machine E'};
data_to_analyze = [data_to_analyze {'cztvsgga_01-Nov-2013_14-58-57-SC5.127.mat'}];
weights(end+1) = 1/5;
machine_labels(end+1) = {'Machine E'};


%memory allocation
data = cell(numel(data_to_analyze),1);
%loading
for cnt = 1:numel(data_to_analyze)
    load([directory data_to_analyze{cnt}])
    data{cnt} = times;
end
clear cnt

numel(data)

%% Example: Computer, GGA, length of signal L=len, for all Ks
% computer = 1;
% algorithm = 1;
% len=2;
% data{computer}{algorithm}(:,len)


%% Plotting all (numel(L) graphs per single test)
if plot_all_graphs_absolute
    for comp = 1:numel(data)
        for len = 1:numel(L)
            %memory allocation
            timesplot = zeros(numel(K),numel(commands));
            for algor = 1:numel(commands)
                %filling
                timesplot(:,algor) = data{comp}{algor}(:,len);
            end
            
            %plot
            figure
            hold on
            for cnt = 1:size(timesplot,2)
                h = plot(K,timesplot(:,cnt), 'Color', colors(cnt), 'Marker', markers(cnt));
                set(h,'LineWidth',2);
            end
            legend(abbrv);
            xlabel('K');
            ylabel('t [ms]');
            title(['Run times: ' machine_labels{comp} ', signal length ' num2str(L(len)) ', average from ' num2str(rep) ' repetitions']);
            set(gcf, 'Color', 'w');
            grid on
        end
    end
end

%% Computing and plotting relative values
if plot_all_graphs_relative
    for comp = 1:numel(data)
        for len = 1:numel(L)
            %memory allocation
            timesplot = zeros(numel(K),numel(commands));
            for algor = 1:numel(commands)
                %filling
                timesplot(:,algor) = data{comp}{algor}(:,len) ./ data{comp}{anchor}(:,len);
            end
            
            %plot
            figure
            hold on
            for cnt = 1:size(timesplot,2)
                h = plot(K,timesplot(:,cnt), 'Color', colors(cnt), 'Marker', markers(cnt));
                set(h,'LineWidth',2);
            end
            legend(abbrv);
            xlabel('K');
            ylabel('t [relative]');
            title(['Run times: ' machine_labels{comp} ', signal length ' num2str(L(len)) ', average from ' num2str(rep) ' repetitions']);
            set(gcf, 'Color', 'w');
            set(gca,'Ylim',[.5 4])
            grid on
        end
    end
end

%% Computing and plotting relative average values
if plot_all_graphs_relative_average
    for len = 1:numel(L)
        %memory allocation
        timesplot = zeros(numel(K),numel(commands));
        
        for algor = 1:numel(commands)
            for comp = 1:numel(data)
                %filling
                timesplot(:,algor) = timesplot(:,algor) + weights(comp) * ((data{comp}{algor}(:,len) ./ data{comp}{anchor}(:,len)));
            end
        end
        %average
        timesplot = timesplot / sum(weights);
        
        %plot
        figure
        hold on
        for cnt = 1:size(timesplot,2)
            h = plot(K,timesplot(:,cnt), 'Color', colors(cnt), 'Marker', markers(cnt));
            set(h,'LineWidth',2);
        end
        legend(abbrv);
        xlabel('K');
        ylabel('t [relative]');
        title(['Average run times, ' num2str(comp) ' measurem. on ' num2str(sum(weights)) ' comps, signal length ' num2str(L(len)) ', from ' num2str(rep) ' repetitions']);
        set(gcf, 'Color', 'w');
        set(gca,'Ylim',[.5 4])
        grid on
    end
end
