/*
 Copyright (C) 2013 Zdenek Prusa <prusa@users.sourceforge.net>.
 This file is part of LTFAT <ltfat.sourceforge.net>

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#define LTFAT_DOUBLE
#include <stdlib.h>
#include <stdio.h>
#include "ltfat.h"
#include "ltfat_types.h"
#include "ltfat_time.h"


#ifndef PI
#   define PI 3.141592653589793
#endif

#ifndef NEXTPOW2
#  define CZT_FLAG CZT_NEXTFASTFFT
#else
#  define CZT_FLAG CZT_NEXTPOW2
#endif

int main( int argc, char *argv[] )
{
   if (argc<3)
   {
      printf("Correct parameters: L, K, nrep\n");
      return(1);
   }
   int nrep = 1;
   if (argc>3)
   {
     nrep = atoi(argv[3]);
   }

   const size_t L = atoi(argv[1]);
   const size_t K = atoi(argv[2]);

   LTFAT_REAL *f = ltfat_malloc(L*sizeof*f);
   LTFAT_COMPLEX *c = ltfat_malloc(K*sizeof*c);

   LTFAT_NAME(fillRand)(f,L);


   double o = 0.1;
   double deltao = 2.0*PI/100.0;


   double st0,st1;
   #ifndef WITH_PLAN
   st0=ltfat_time();
   for (int jj=0;jj<nrep;jj++)
   {
      LTFAT_NAME(chzt_fac)(f,L,1,K,deltao,o,c);
   }
   st1=ltfat_time();
   #else
   LTFAT_NAME(chzt_plan) p = LTFAT_NAME(chzt_fac_init)(K,L,deltao,o,FFTW_MEASURE,CZT_FLAG);
   st0=ltfat_time();
   for (int jj=0;jj<nrep;jj++)
   {
      LTFAT_NAME(chzt_fac_execute)(p,f,1,c);
   }
   st1=ltfat_time();
   LTFAT_NAME(chzt_done)(p);
   #endif

   //printf("Length: %i, avr. %f ms \n",L,(st1-st0)/((double)nrep));
   printf("%i, %f\n",L,(st1-st0)/((double)nrep));

   ltfat_free(f);
   ltfat_free(c);

   return 0;
}
