/*
 Copyright (C) 2013 Zdenek Prusa <prusa@users.sourceforge.net>.
 This file is part of LTFAT <ltfat.sourceforge.net>

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#define LTFAT_DOUBLE
#include <stdlib.h>
#include <stdio.h>
#include "ltfat.h"
#include "ltfat_types.h"
#include "ltfat_time.h"

int main( int argc, char *argv[] )
{
   if (argc<3)
   {
      printf("Correct parameters: L, M, nrep\n");     
      return(1);
   }
   int nrep = 1;
   if (argc>3)
   {
     nrep = atoi(argv[3]);
   }
   
   const size_t L = atoi(argv[1]);
   const size_t M = atoi(argv[2]);
   
   //printf("1) Before allocation\n");
   LTFAT_REAL *f = ltfat_malloc(L*sizeof*f);
   LTFAT_COMPLEX *c = ltfat_malloc(M*sizeof*c);
   double *indVec = ltfat_malloc(M*sizeof*indVec);
   //printf("2) Before filling\n");
   LTFAT_NAME_REAL(fillRand)(f,L);

   for(size_t m=0;m<M;m++)
   {
      indVec[m]=0.1+((double)m)/100.0;
   }
      
	  
   //printf("3) Before call\n");
   double st0,st1;
   #ifndef WITH_PLAN
      st0=ltfat_time();
      for (int jj=0;jj<nrep;jj++)
      {
         LTFAT_NAME_REAL(gga)(f,indVec,L,1,M,c);
      }
      st1=ltfat_time();
   #else
      //printf("4) Before plan\n");
      LTFAT_NAME_REAL(gga_plan) p = LTFAT_NAME_REAL(gga_init)(indVec,M,L);
      st0=ltfat_time();  

	  //printf("5) Before loop\n");
      for (int jj=0;jj<nrep;jj++)
      {
         LTFAT_NAME_REAL(gga_execute)(p,f,1,c);
      }
	  st1=ltfat_time();
	  //printf("6) Before plan delete\n");
      LTFAT_NAME_REAL(gga_done)(p);

   #endif
   
   
   //printf("L=%d, M=%d, nrep=%d\n",L,M,nrep);
   //printf("Length: %i, avr. %f ms \n",L,(st1-st0)/((double)nrep));
    printf("%i, %f\n",L,(st1-st0)/((double)nrep));
   
  
   ltfat_free(f);
   ltfat_free(c);
   ltfat_free(indVec);
   return 0;
}
